==> jc-1.4.0.tar.gz: gnu/java/locale/LocaleInformation__5fes__5fNI.h <==
// public class gnu.java.locale.LocaleInformation_es_NI

// class file dependencies
// @dep_class ce429a1953f56e1d gnu_java_locale_LocaleInformation__5fes__5fNI
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fes__5fNI_H_
#define _JC_gnu_java_locale_LocaleInformation__5fes__5fNI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$refs	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vmethods	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtable	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtype	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$fields_struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object *);

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object *);
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vmethods	gnu_java_locale_LocaleInformation__5fes__5fNI;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$refs {
    _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_refs	gnu_java_locale_LocaleInformation__5fes__5fNI;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_nonrefs	gnu_java_locale_LocaleInformation__5fes__5fNI;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object {
	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtype _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fes__5fNI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fes__5fNI_H_ */

==> jc-1.4.5.tar.gz: gnu/java/locale/LocaleInformation__5fes__5fNI.h <==
// public class gnu.java.locale.LocaleInformation_es_NI

// class file dependencies
// @dep_class ce429a1953f56e1d gnu_java_locale_LocaleInformation__5fes__5fNI
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 33ddaf617676c508 java_util_ListResourceBundle
// @dep_class b0f2ff51263ebf06 java_util_ResourceBundle

// header file dependencies
// @dep_header java_util_ListResourceBundle

#include "java/util/ListResourceBundle.h"

#ifndef _JC_gnu_java_locale_LocaleInformation__5fes__5fNI_H_
#define _JC_gnu_java_locale_LocaleInformation__5fes__5fNI_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_refs	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_nonrefs	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$refs	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$refs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$nonrefs	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$nonrefs;
typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object;

typedef struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$fields_struct	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$fields_struct;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vmethods	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vmethods;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtable	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtable;
typedef const struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtype	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtype;

// Class fields structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$fields_struct {
	_jc_object_array	*contents;
};
extern _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$fields_struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$class_fields;

// Constructors
extern void _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object *) _JC_JCNI_ATTR;

// Virtual methods
extern _jc_object_array *_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$method$getContents$77295dd4f2da9d10(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$method_info$getContents$77295dd4f2da9d10;

// Static methods
extern void _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vmethods {
	_jc_object_array	*(*getContents$77295dd4f2da9d10)(_jc_env *, struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_util_ResourceBundle$vmethods	java_util_ResourceBundle;
	_jc_java_util_ListResourceBundle$vmethods	java_util_ListResourceBundle;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vmethods	gnu_java_locale_LocaleInformation__5fes__5fNI;
};

// Vtype
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtype {
	_jc_type			type;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_refs {
};

// Reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$refs {
    _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_refs	gnu_java_locale_LocaleInformation__5fes__5fNI;
    _jc_java_util_ListResourceBundle$sub_refs	java_util_ListResourceBundle;
    _jc_java_util_ResourceBundle$sub_refs	java_util_ResourceBundle;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_util_ResourceBundle$sub_nonrefs	java_util_ResourceBundle;
    _jc_java_util_ListResourceBundle$sub_nonrefs	java_util_ListResourceBundle;
    _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$sub_nonrefs	gnu_java_locale_LocaleInformation__5fes__5fNI;
};

// Object instance structure
struct _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$object {
	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtype	*vtype;
	_jc_gnu_java_locale_LocaleInformation__5fes__5fNI$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$vtype _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_java_locale_LocaleInformation__5fes__5fNI, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_java_locale_LocaleInformation__5fes__5fNI$class_object;

#endif	/* _JC_gnu_java_locale_LocaleInformation__5fes__5fNI_H_ */
